/***********************************************************
 * $Id: JobStatusImpl.java 934 2013-12-11 20:26:18Z util $
 * 
 * scheduler utilities of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 04.10.2012
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.sched.impl;

import java.util.UUID;
import java.util.concurrent.Future;

import org.clazzes.util.sched.IJobStatus;

/**
 *  The actual implementation of a job status.
 */
class JobStatusImpl implements IJobStatus {

    private Future<?> future = null;
    private Object result = null;
    private Throwable exception = null;
    private boolean running;
    private long finishedMillis = -1L;
    private Long nextExecutionDelay;
    private UUID uuid;
    
    public JobStatusImpl(UUID uuid) {
        super();
        this.uuid = uuid;
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.sched.IJobStatus#isCancelled()
     */
    @Override
    public boolean isCancelled() {
        
        if (this.future == null) {
            return false;
        }
        else {
            return this.future.isCancelled();
        }
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.sched.IJobStatus#isDone()
     */
    @Override
    public synchronized boolean isDone() {
        
        if (this.running) {
            return false;
        }
        
        if (this.future == null) {
            return false;
        }
        else {
            return this.future.isDone();
        }
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.sched.IJobStatus#getResult()
     */
    @Override
    public synchronized Object getResult() {
        
        return this.result;
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.sched.IJobStatus#getException()
     */
    @Override
    public synchronized Throwable getException() {
        
        return this.exception;
    }
    
    public synchronized void setRunning(boolean running) {
        this.running = running;
    }

    /**
     * @param result the result of the job to set.
     */
    protected synchronized void setResult(Object result, Long nextExecutionDelay) {
        this.result = result;
        this.running = false;
        this.finishedMillis = System.currentTimeMillis();
        this.nextExecutionDelay = nextExecutionDelay;
    }

    /**
     * @param exception the exception to set
     */
    protected synchronized void setException(Throwable exception, Long nextExecutionDelay) {
        this.exception = exception;
        this.running = false;
        this.finishedMillis = System.currentTimeMillis();
        this.nextExecutionDelay = nextExecutionDelay;
    }

    @Override
    public synchronized Long getNextExecutionDelay() {
        return this.nextExecutionDelay;
    }

    /**
     * @param future the future to set
     */
    public void setFuture(Future<?> future) {
        this.future = future;
    }

    @Override
    public long getFinishedMillis() {
        return this.finishedMillis;
    }

    /**
     * @return The underlying future.
     */
    public Future<?> getFuture() {
        return this.future;
    }
    
    public UUID getUUID() {
        return this.uuid;
    }
    
}
